@@ -217,7 +217,7 @@ def _get_updated_version_specifier(
     requirement_operator: str
     version: str
     requirement_operator, version = re.match(
-        r'^\s*([~<>=]*)\s*(.*?)\s*$',
+        r'^\s*([!~<>=]*)\s*(.*?)\s*$',
         version_specifier
     ).groups()
     if not requirement_operator:
@@ -315,13 +315,13 @@ def update_requirements_versions(
             (package_identifier not in ignore) and
             (package_identifier.split('[')[0] not in ignore)
         ):
-            try:
-                requirements[index] = get_updated_version_requirement(
-                    version_requirement,
-                    default_operator=default_operator
-                )
-            except:  # noqa
-                warn(''.join(format_exception(*sys.exc_info())))
+            #try:
+            requirements[index] = get_updated_version_requirement(
+                version_requirement,
+                default_operator=default_operator
+            )
+            #except:  # noqa
+            #    warn(''.join(format_exception(*sys.exc_info())))
 
 
 def update_setup(
